.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`segmentation`
===========================
.. automodule:: skimage.segmentation

.. currentmodule:: skimage.segmentation
.. autosummary::

   skimage.segmentation.random_walker
   skimage.segmentation.active_contour
   skimage.segmentation.felzenszwalb
   skimage.segmentation.slic
   skimage.segmentation.quickshift
   skimage.segmentation.find_boundaries
   skimage.segmentation.mark_boundaries
   skimage.segmentation.clear_border
   skimage.segmentation.join_segmentations
   skimage.segmentation.relabel_from_one
   skimage.segmentation.relabel_sequential
   skimage.segmentation.watershed
   skimage.segmentation.chan_vese
   skimage.segmentation.morphological_geodesic_active_contour
   skimage.segmentation.morphological_chan_vese
   skimage.segmentation.inverse_gaussian_gradient
   skimage.segmentation.circle_level_set
   skimage.segmentation.checkerboard_level_set



random_walker
-------------

.. autofunction:: skimage.segmentation.random_walker

active_contour
--------------

.. autofunction:: skimage.segmentation.active_contour

felzenszwalb
------------

.. autofunction:: skimage.segmentation.felzenszwalb

slic
----

.. autofunction:: skimage.segmentation.slic

quickshift
----------

.. autofunction:: skimage.segmentation.quickshift

find_boundaries
---------------

.. autofunction:: skimage.segmentation.find_boundaries

mark_boundaries
---------------

.. autofunction:: skimage.segmentation.mark_boundaries

clear_border
------------

.. autofunction:: skimage.segmentation.clear_border

join_segmentations
------------------

.. autofunction:: skimage.segmentation.join_segmentations

relabel_from_one
----------------

.. autofunction:: skimage.segmentation.relabel_from_one

relabel_sequential
------------------

.. autofunction:: skimage.segmentation.relabel_sequential

watershed
---------

.. autofunction:: skimage.segmentation.watershed

chan_vese
---------

.. autofunction:: skimage.segmentation.chan_vese

morphological_geodesic_active_contour
-------------------------------------

.. autofunction:: skimage.segmentation.morphological_geodesic_active_contour

morphological_chan_vese
-----------------------

.. autofunction:: skimage.segmentation.morphological_chan_vese

inverse_gaussian_gradient
-------------------------

.. autofunction:: skimage.segmentation.inverse_gaussian_gradient

circle_level_set
----------------

.. autofunction:: skimage.segmentation.circle_level_set

checkerboard_level_set
----------------------

.. autofunction:: skimage.segmentation.checkerboard_level_set

